@@ -1,8 +1,81 @@
-package Class::Accessor::Class;
-use base qw(Class::Accessor);
-
-use warnings;
 use strict;
+use warnings;
+package Class::Accessor::Class;
+{
+  $Class::Accessor::Class::VERSION = '0.503';
+}
+use Class::Accessor 0.16 ();
+use parent 'Class::Accessor';
+# ABSTRACT: simple class variable accessors
+
+
+sub mk_class_accessors {
+	my ($self, @fields) = @_;
+
+  ## no critic (ProhibitNoStrict)
+  no strict 'refs';
+  for my $field (@fields) {
+    *{"${self}::$field"} = $self->make_class_accessor($field);
+  }
+}
+
+
+sub mk_package_accessors {
+	my ($self, @fields) = @_;
+
+  ## no critic (ProhibitNoStrict)
+  no strict 'refs';
+  for my $field (@fields) {
+    *{"${self}::$field"} = $self->make_package_accessor($field);
+  }
+}
+
+
+{
+	my %accessor;
+
+	sub make_class_accessor {
+		my ($class, $field) = @_;
+
+		return $accessor{$class}{$field}
+			if $accessor{$class}{$field};
+
+		my $field_value;
+
+		$accessor{$class}{$field} = sub {
+			my $class = shift;
+
+			return @_
+				? ($field_value = $_[0])
+				:  $field_value;
+		}
+	}
+}
+
+
+sub make_package_accessor {
+	my ($self, $field) = @_;
+	my $class = ref $self || $self;
+
+	my $varname = "$class\:\:$field";
+	return sub {
+		my $class = shift;
+
+    ## no critic (ProhibitNoStrict)
+    no strict 'refs';
+		return @_
+			? (${$varname} = $_[0])
+			:  ${$varname}
+	}
+}
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
@@ -10,13 +83,7 @@ Class::Accessor::Class - simple class variable accessors
 
 =head1 VERSION
 
-version 0.501
-
- $Id: /my/cs/projects/claccl/trunk/lib/Class/Accessor/Class.pm 27922 2006-11-13T16:05:47.533928Z rjbs  $
-
-=cut
-
-our $VERSION = '0.501';
+version 0.503
 
 =head1 SYNOPSIS
 
@@ -70,18 +137,6 @@ and can use its methods.
 This method adds accessors for the named class variables.  The accessor will
 get or set a lexical variable to which the accessor is the only access.
 
-=cut
-
-sub mk_class_accessors {
-	my ($self, @fields) = @_;
-
-  ## no critic (ProhibitNoStrict)
-  no strict 'refs';
-  for my $field (@fields) {
-    *{"${self}::$field"} = $self->make_class_accessor($field);
-  }
-}
-
 =head2 mk_package_accessors
 
  package Foo;
@@ -96,18 +151,6 @@ sub mk_class_accessors {
 This method adds accessors for the named class variables.  The accessor will
 get or set the named variable in the package's symbol table.
 
-=cut
-
-sub mk_package_accessors {
-	my ($self, @fields) = @_;
-
-  ## no critic (ProhibitNoStrict)
-  no strict 'refs';
-  for my $field (@fields) {
-    *{"${self}::$field"} = $self->make_package_accessor($field);
-  }
-}
-
 =head1 DETAILS
 
 =head2 make_class_accessor
@@ -117,29 +160,6 @@ sub mk_package_accessors {
 This method generates a subroutine reference which acts as an accessor for the
 named field. 
 
-=cut
-
-{
-	my %accessor;
-
-	sub make_class_accessor {
-		my ($class, $field) = @_;
-
-		return $accessor{$class}{$field}
-			if $accessor{$class}{$field};
-
-		my $field_value;
-
-		$accessor{$class}{$field} = sub {
-			my $class = shift;
-
-			return @_
-				? ($field_value = $_[0])
-				:  $field_value;
-		}
-	}
-}
-
 =head2 make_package_accessor
 
  $accessor = Class->make_package_accessor($field);
@@ -151,42 +171,15 @@ table.
 This can be useful for dealing with legacy code, but using package variables is
 almost never a good idea for new code.  Use this with care.
 
-=cut
-
-sub make_package_accessor {
-	my ($self, $field) = @_;
-	my $class = ref $self || $self;
-
-	my $varname = "$class\:\:$field";
-	return sub {
-		my $class = shift;
-
-    ## no critic (ProhibitNoStrict)
-    no strict 'refs';
-		return @_
-			? (${$varname} = $_[0])
-			:  ${$varname}
-	}
-}
-
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-class-accessor-class@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2004 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2004-2006 Ricardo Signes, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
